@@ -11,11 +11,6 @@ test_that("var_types will only react to data.frame(including data.table)", {
   expect_error(var_types(list(1:10,"a"), "c"), "Please supply a data.frame/data.table as the value of tbl")
 })
 
-test_that("var_types will throw error when the length of 'types' doesn't match up", {
-  expect_error(var_types(mtcars, "qqqqqqc"), "The length of the string you entered doesn't match the number of variables")
-  expect_error(var_types(group_by(mtcars, am), "qcqqqqqccc"), "The length of the string you entered doesn't match the number of variables")
-})
-
 test_that("var_types will throw error when the 'types' string contains characters other than 'q' and 'c'", {
   expect_error(var_types(mtcars, "qcqqqqqcccw"), 'Unrecognizable character\\(s\\) detected!! Please review your input and use "q" and "c" to denote quantitative and categorical variables')
 })
